@@ -36,7 +36,7 @@
 #include "duchain/helpers.h"
 
 #include <QDebug>
-#include "../codecompletiondebug.h"
+#include <codecompletiondebug.h>
 
 using namespace KDevelop;
 using namespace KTextEditor;
@@ -84,7 +84,7 @@ QVariant FunctionDeclarationCompletionItem::data(const QModelIndex& index, int r
             if ( index.column() == KDevelop::CodeCompletionModel::Arguments ) {
                 if (FunctionType::Ptr functionType = dec->type<FunctionType>()) {
                     QString ret;
-                    createArgumentList(dec, ret, 0, 0, false);
+                    createArgumentList(dec, ret, nullptr, 0, false);
                     return ret;
                 }
             }
@@ -110,10 +110,11 @@ QVariant FunctionDeclarationCompletionItem::data(const QModelIndex& index, int r
                     createArgumentList(dec, ret, &highlight, atArgument(), false);
                 }
                 else {
-                    createArgumentList(dec, ret, 0, false);
+                    createArgumentList(dec, ret, nullptr, false);
                 }
                 return QVariant(highlight);
             }
+            break;
         }
         case KDevelop::CodeCompletionModel::MatchQuality: {
             if (    m_typeHint == PythonCodeCompletionContext::IterableRequested
